@@ -1,24 +1,20 @@
 module Main where
 
 -- {{{ Imports
-import Hbro.Core
+import Hbro.Hbro
 import Hbro.Types
 
 import Paths_hbro
-
-import System.Directory
 -- }}}
 
 -- | Default main function provided as example.
 main :: IO ()
 main = do
-    home   <- getHomeDirectory
-    tmp    <- getTemporaryDirectory
-    uiFile <- getDataFileName "examples/ui.xml"
-
 --     putStrLn "[WARNING] You are running the default configuration which provides hardly no feature."
 --     putStrLn "[WARNING] You should copy the example configuration files hbro.hs and ui.xml in ~/.config/hbro/hbro and start hacking them."
 
-    launchHbro $ (defaultConfig home tmp) {
+    uiFile <- getDataFileName "examples/ui.xml"
+    
+    launchHbro $ \d -> (defaultConfig d) {
         mUIFile = uiFile
     }
